mesagrid
========

.. raw:: html

   <div style="display: inline-block;">
      <a href="https://pypi.python.org/pypi/mesagrid">
         <img src="https://img.shields.io/pypi/v/mesagrid.svg" alt="PyPI version" />
      </a>
      <a href="https://app.travis-ci.com/github/earlbellinger/mesagrid">
         <img src="https://app.travis-ci.com/earlbellinger/mesagrid.svg" alt="Build Status" />
      </a>
      <a href="https://mesagrid.readthedocs.io/en/latest/?version=latest">
         <img src="https://readthedocs.org/projects/mesagrid/badge/?version=latest" alt="Documentation Status" />
      </a>
      <a href="https://github.com/earlbellinger/mesagrid/blob/main/LICENSE">
         <img src="https://img.shields.io/badge/license-MIT-orange.svg?style=flat" alt="MIT License" />
      </a>
   </div>

A python library for parsing, analyzing, and visualizing grids of MESA tracks and models, including stellar pulsation data. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   contributing
   authors
   history
